<?xml version="1.0" encoding="ISO-8859-1" ?>
<!--
  convert.xlst
  Copyright  2006-2008 Kinook Software, Inc.
  http://www.ultrarecall.com/

  Converts Ultra Recall XML export to an HTML table of contents file, used
  in conjunction with index.html to display a UR tree + details in a browser.
  See http://www.kinook.com/Forum/showthread.php?threadid=2054 for details.

-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:output method="html" encoding="UTF-8" indent="yes" />
	<xsl:param name="attributes">no</xsl:param>

	<xsl:template match="/oml/body">

		<!-- boilerplate HTML for page -->
		<html>
		<head>
			<script type="text/javascript">
				// toggle the expand/collapse state of the given div tag
				function toggle(divID)
				{
					var div = document.getElementById(divID);
					if (div)
						div.style.display = (div.style.display == "none") ? "block" : "none";
				}
			</script>
		</head>
		<body>

			<p>Click on an icon to expand or collapse a node. Click on an item's text to view its details  in the right pane.</p>

			<div id="tree">

				<!-- process outline nodes -->
				<xsl:apply-templates select="outline" />

			</div>

		</body>
		</html>

	</xsl:template>

	<xsl:template match="outline">
		<!-- calculate item indent level -->
		<xsl:variable name="num"><xsl:number level="multiple" count="outline" /></xsl:variable>
		<xsl:variable name="level"><xsl:value-of select="string-length($num) - string-length(translate($num, '.', '')) + 
		1" /></xsl:variable>

		<!-- use stored content file if available or RTF if not, finally URL -->
		<xsl:variable name="url">
			<xsl:choose>
				<xsl:when test="Item[@name='Stored Document']">
					<xsl:value-of select="Item[@name='Stored Document']" />
				</xsl:when>
				<xsl:when test="Item[@name='Item Details (RTF)']">
					<xsl:value-of select="Item[@name='Item Details (RTF)']" />
				</xsl:when>
				<xsl:when test="Item[@name='URL']">
					<xsl:value-of select="Item[@name='URL']" />
				</xsl:when>
			</xsl:choose>
		</xsl:variable>

		<!-- expand only first level by default -->
		<xsl:variable name="expand">
			<xsl:choose>
				<xsl:when test="$level &lt; 2">block</xsl:when>
				<xsl:otherwise>none</xsl:otherwise>
			</xsl:choose>
		</xsl:variable>


		<!-- HTML for this item -->
		<table border="0" cellpadding="0" cellspacing="0"><tr valign="center">
			<td width="{$level * 20}" align="right">
				<a href="javascript:toggle('{generate-id()}')"><img src="{Item[@name='Icon']}" width="16px" height="16px" border="0" /></a>
			</td>
			<td align="left">
				<a href="{translate($url, '\', '/')}" target="content" ondblclick="javascript:toggle('{generate-id()}')"><xsl:value-of select="@text" /></a>
			</td>
		</tr></table>

		<div id="{generate-id()}" style="display:{$expand}">

			<!-- recursively process outline nodes -->
			<xsl:apply-templates select="outline" />

			<xsl:if test="$attributes='yes'">
				<!-- item attributes -->
				<table border="0" cellpadding="0" cellspacing="0"><tr valign="center">
					<td width="{($level+1) * 20}" align="right">
						<a href="javascript:toggle('A{generate-id()}')"><img src="{Item[@name='Icon']}" width="16px" height="16px" border="0" /></a>
					</td>
					<td align="left">Attributes</td>
				</tr></table>

				<div id="A{generate-id()}" style="display:none">
					<!-- process attribute values -->
					<xsl:apply-templates select="Item">
						<xsl:with-param name="level" select="$level+1" />
					</xsl:apply-templates>
				</div>
			</xsl:if>

		</div>

	</xsl:template>

	<!-- process attributes -->
	<xsl:template match="Item">
		<xsl:param name="level" />

		<table border="0" cellpadding="0" cellspacing="0"><tr valign="center">
			<td width="{$level * 20 + 10}" />
			<td align="left"><b><xsl:value-of select="@name" />: </b><xsl:value-of select="." /></td>
		</tr></table>

	</xsl:template>

</xsl:stylesheet>
